smartcard.pyro.server.RemoteReaderServer.RemoteReader

# ``smartcard`.`pyro`.`server`.`RemoteReaderServer`.`RemoteReader``

class documentation

`class RemoteReader(Reader, Pyro.core.ObjBase):`

View In Hierarchy

Remote reader class that embeds a local reader.

Method | `__init__` | Encapsulate a local reader and publish as a pyro remote reader.
Method | `addtoreadergroup` | Add reader to a reader group.
Method | `createConnection` | Return a card connection thru the reader.
Method | `removefromreadergroup` | Remove a reader from a reader group
Instance Variable | `name` | Undocumented
Instance Variable | `readerobj` | Undocumented

Inherited from `Reader`:

Method | `__eq__` | Returns True if self==other (same name).
Method | `__hash__` | Returns a hash value for this object (self.name is unique).
Method | `__repr__` | Returns card reader name string for `object` calls.
Method | `__str__` | Returns card reader name string for str(object) calls.

def __init__(self, reader):
overrides `smartcard.reader.Reader.Reader.__init__`

Encapsulate a local reader and publish as a pyro remote reader.

reader: the local reader to publish remotely

def addtoreadergroup(self, groupname):
overrides `smartcard.reader.Reader.Reader.addtoreadergroup`

Add reader to a reader group.

def createConnection(self):
overrides `smartcard.reader.Reader.Reader.createConnection`

Return a card connection thru the reader.

def removefromreadergroup(self, groupname):
overrides `smartcard.reader.Reader.Reader.removefromreadergroup`

Remove a reader from a reader group

name =
overrides `smartcard.reader.Reader.Reader.name`

Undocumented

readerobj =

Undocumented